@@ -23,7 +23,7 @@
 //  @licend The above is the entire license notice for the JavaScript
 //  code in this page (or file).
 //
-// @source http://e-valkov.org/linterna-magica
+// @source http://linterna-magica.nongnu.org
 
 // END OF LICENSE HEADER
 
@@ -121,12 +121,15 @@ function LinternaMagica(params)
 	this.player_timers = new Array();
     }
 
+    if (!this.plugin_is_installed &&
+	/dailymotion\.com/i.test(window.location.hostname))
+    {
+	this.request_video_link({video_id: window.location.pathname});
+    }
     // If there is a plugin installed do not search in scripts.
-    // Exception for blip.tv. This is the easiesy way to
-    // support it with installed plugin.
-    if (!this.plugin_is_installed ||
-	/blip\.tv/i.test(window.location.hostname) ||
-	/myvideo\.de/i.test(window.location.hostname))
+    else if (!this.plugin_is_installed ||
+	     /myvideo\.de/i.test(window.location.hostname) ||
+	     /theonion\.com/i.test(window.location.hostname))
     {
 	this.log("LinternaMagica.constructor:\n"+
 		 "Examining scripts.", 4);
@@ -178,7 +181,7 @@ LinternaMagica.prototype.name =  "Linterna Mágica";
 
 // Release date string in POISIX time format (date +"%s")
 // FIXME: Add real string
-LinternaMagica.prototype.release_date = "1303812612";
+LinternaMagica.prototype.release_date = "1308131989";
 
 // The URL with information about the latest version. Must
 // return JSONP data:
@@ -187,7 +190,7 @@ LinternaMagica.prototype.release_date = "1303812612";
 //    version: <version>,  // string 
 //});
 LinternaMagica.prototype.updates_page =
-    "http://e-valkov.org/linterna-magica/downloads/updates.js";
+    "http://linterna-magica.nongnu.org/downloads/updates.js";
 //    "http://localhost/linterna-magica/downloads/updates.js";
 
 LinternaMagica.prototype.description =
@@ -208,7 +211,7 @@ LinternaMagica.prototype.license_link =
     "http://www.gnu.org/licenses/gpl.html";
 
 LinternaMagica.prototype.homepage = 
-    "http://e-valkov.org/linterna-magica";
+    "http://linterna-magica.nongnu.org";
 // "http://localhost/lm";
 
 // This is filled during build from the Makefile
