@@ -23,7 +23,7 @@
 //  @licend The above is the entire license notice for the JavaScript
 //  code in this page (or file).
 //
-// @source http://e-valkov.org/linterna-magica
+// @source http://linterna-magica.nongnu.org
 
 // END OF LICENSE HEADER
 
@@ -536,6 +536,13 @@ LinternaMagica.prototype.create_video_object = function(object_data)
 	}
     }
 
+    // Bug #33504 https://savannah.nongnu.org/bugs/?33504
+    if (/youtube\.com/i.test(window.location.hostname))
+    {
+	object_data.parent.style.setProperty("overflow", 
+					     "visible", "important");
+    }
+
     // Temporary
     // parent.style.setProperty("border", "1px solid red", "important");
 
